/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __CS_LOGIND_SESSION_PROXY_H__
#define __CS_LOGIND_SESSION_PROXY_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.freedesktop.login1.Session */

#define CS_TYPE_LOGIND_SESSION (cs_logind_session_get_type ())
#define CS_LOGIND_SESSION(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_LOGIND_SESSION, CsLogindSession))
#define CS_IS_LOGIND_SESSION(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_LOGIND_SESSION))
#define CS_LOGIND_SESSION_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), CS_TYPE_LOGIND_SESSION, CsLogindSessionIface))

struct _CsLogindSession;
typedef struct _CsLogindSession CsLogindSession;
typedef struct _CsLogindSessionIface CsLogindSessionIface;

struct _CsLogindSessionIface
{
  GTypeInterface parent_iface;


  gboolean  (*get_active) (CsLogindSession *object);

  void (*lock) (
    CsLogindSession *object);

  void (*unlock) (
    CsLogindSession *object);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsLogindSession, g_object_unref)
#endif

GType cs_logind_session_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *cs_logind_session_interface_info (void);
guint cs_logind_session_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus signal emissions functions: */
void cs_logind_session_emit_lock (
    CsLogindSession *object);

void cs_logind_session_emit_unlock (
    CsLogindSession *object);



/* D-Bus property accessors: */
gboolean cs_logind_session_get_active (CsLogindSession *object);
void cs_logind_session_set_active (CsLogindSession *object, gboolean value);


/* ---- */

#define CS_TYPE_LOGIND_SESSION_PROXY (cs_logind_session_proxy_get_type ())
#define CS_LOGIND_SESSION_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_LOGIND_SESSION_PROXY, CsLogindSessionProxy))
#define CS_LOGIND_SESSION_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_LOGIND_SESSION_PROXY, CsLogindSessionProxyClass))
#define CS_LOGIND_SESSION_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_LOGIND_SESSION_PROXY, CsLogindSessionProxyClass))
#define CS_IS_LOGIND_SESSION_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_LOGIND_SESSION_PROXY))
#define CS_IS_LOGIND_SESSION_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_LOGIND_SESSION_PROXY))

typedef struct _CsLogindSessionProxy CsLogindSessionProxy;
typedef struct _CsLogindSessionProxyClass CsLogindSessionProxyClass;
typedef struct _CsLogindSessionProxyPrivate CsLogindSessionProxyPrivate;

struct _CsLogindSessionProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  CsLogindSessionProxyPrivate *priv;
};

struct _CsLogindSessionProxyClass
{
  GDBusProxyClass parent_class;
};

GType cs_logind_session_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsLogindSessionProxy, g_object_unref)
#endif

void cs_logind_session_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsLogindSession *cs_logind_session_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
CsLogindSession *cs_logind_session_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void cs_logind_session_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsLogindSession *cs_logind_session_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
CsLogindSession *cs_logind_session_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define CS_TYPE_LOGIND_SESSION_SKELETON (cs_logind_session_skeleton_get_type ())
#define CS_LOGIND_SESSION_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_LOGIND_SESSION_SKELETON, CsLogindSessionSkeleton))
#define CS_LOGIND_SESSION_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_LOGIND_SESSION_SKELETON, CsLogindSessionSkeletonClass))
#define CS_LOGIND_SESSION_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_LOGIND_SESSION_SKELETON, CsLogindSessionSkeletonClass))
#define CS_IS_LOGIND_SESSION_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_LOGIND_SESSION_SKELETON))
#define CS_IS_LOGIND_SESSION_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_LOGIND_SESSION_SKELETON))

typedef struct _CsLogindSessionSkeleton CsLogindSessionSkeleton;
typedef struct _CsLogindSessionSkeletonClass CsLogindSessionSkeletonClass;
typedef struct _CsLogindSessionSkeletonPrivate CsLogindSessionSkeletonPrivate;

struct _CsLogindSessionSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  CsLogindSessionSkeletonPrivate *priv;
};

struct _CsLogindSessionSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType cs_logind_session_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsLogindSessionSkeleton, g_object_unref)
#endif

CsLogindSession *cs_logind_session_skeleton_new (void);


G_END_DECLS

#endif /* __CS_LOGIND_SESSION_PROXY_H__ */
