/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __CS_CINNAMON_PROXY_H__
#define __CS_CINNAMON_PROXY_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.Cinnamon */

#define CS_TYPE_CINNAMON (cs_cinnamon_get_type ())
#define CS_CINNAMON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_CINNAMON, CsCinnamon))
#define CS_IS_CINNAMON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_CINNAMON))
#define CS_CINNAMON_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), CS_TYPE_CINNAMON, CsCinnamonIface))

struct _CsCinnamon;
typedef struct _CsCinnamon CsCinnamon;
typedef struct _CsCinnamonIface CsCinnamonIface;

struct _CsCinnamonIface
{
  GTypeInterface parent_iface;

  gboolean  (*get_expo_active) (CsCinnamon *object);

  gboolean  (*get_overview_active) (CsCinnamon *object);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsCinnamon, g_object_unref)
#endif

GType cs_cinnamon_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *cs_cinnamon_interface_info (void);
guint cs_cinnamon_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus property accessors: */
gboolean cs_cinnamon_get_overview_active (CsCinnamon *object);
void cs_cinnamon_set_overview_active (CsCinnamon *object, gboolean value);

gboolean cs_cinnamon_get_expo_active (CsCinnamon *object);
void cs_cinnamon_set_expo_active (CsCinnamon *object, gboolean value);


/* ---- */

#define CS_TYPE_CINNAMON_PROXY (cs_cinnamon_proxy_get_type ())
#define CS_CINNAMON_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_CINNAMON_PROXY, CsCinnamonProxy))
#define CS_CINNAMON_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_CINNAMON_PROXY, CsCinnamonProxyClass))
#define CS_CINNAMON_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_CINNAMON_PROXY, CsCinnamonProxyClass))
#define CS_IS_CINNAMON_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_CINNAMON_PROXY))
#define CS_IS_CINNAMON_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_CINNAMON_PROXY))

typedef struct _CsCinnamonProxy CsCinnamonProxy;
typedef struct _CsCinnamonProxyClass CsCinnamonProxyClass;
typedef struct _CsCinnamonProxyPrivate CsCinnamonProxyPrivate;

struct _CsCinnamonProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  CsCinnamonProxyPrivate *priv;
};

struct _CsCinnamonProxyClass
{
  GDBusProxyClass parent_class;
};

GType cs_cinnamon_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsCinnamonProxy, g_object_unref)
#endif

void cs_cinnamon_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsCinnamon *cs_cinnamon_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
CsCinnamon *cs_cinnamon_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void cs_cinnamon_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsCinnamon *cs_cinnamon_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
CsCinnamon *cs_cinnamon_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define CS_TYPE_CINNAMON_SKELETON (cs_cinnamon_skeleton_get_type ())
#define CS_CINNAMON_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_CINNAMON_SKELETON, CsCinnamonSkeleton))
#define CS_CINNAMON_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_CINNAMON_SKELETON, CsCinnamonSkeletonClass))
#define CS_CINNAMON_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_CINNAMON_SKELETON, CsCinnamonSkeletonClass))
#define CS_IS_CINNAMON_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_CINNAMON_SKELETON))
#define CS_IS_CINNAMON_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_CINNAMON_SKELETON))

typedef struct _CsCinnamonSkeleton CsCinnamonSkeleton;
typedef struct _CsCinnamonSkeletonClass CsCinnamonSkeletonClass;
typedef struct _CsCinnamonSkeletonPrivate CsCinnamonSkeletonPrivate;

struct _CsCinnamonSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  CsCinnamonSkeletonPrivate *priv;
};

struct _CsCinnamonSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType cs_cinnamon_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsCinnamonSkeleton, g_object_unref)
#endif

CsCinnamon *cs_cinnamon_skeleton_new (void);


G_END_DECLS

#endif /* __CS_CINNAMON_PROXY_H__ */
