/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __CS_MUFFIN_DISPLAYCONFIG_PROXY_H__
#define __CS_MUFFIN_DISPLAYCONFIG_PROXY_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.cinnamon.Muffin.DisplayConfig */

#define CS_TYPE_MUFFIN_DISPLAY_CONFIG (cs_muffin_display_config_get_type ())
#define CS_MUFFIN_DISPLAY_CONFIG(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_MUFFIN_DISPLAY_CONFIG, CsMuffinDisplayConfig))
#define CS_IS_MUFFIN_DISPLAY_CONFIG(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_MUFFIN_DISPLAY_CONFIG))
#define CS_MUFFIN_DISPLAY_CONFIG_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), CS_TYPE_MUFFIN_DISPLAY_CONFIG, CsMuffinDisplayConfigIface))

struct _CsMuffinDisplayConfig;
typedef struct _CsMuffinDisplayConfig CsMuffinDisplayConfig;
typedef struct _CsMuffinDisplayConfigIface CsMuffinDisplayConfigIface;

struct _CsMuffinDisplayConfigIface
{
  GTypeInterface parent_iface;


  gboolean (*handle_get_current_state) (
    CsMuffinDisplayConfig *object,
    GDBusMethodInvocation *invocation);

  void (*monitors_changed) (
    CsMuffinDisplayConfig *object);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsMuffinDisplayConfig, g_object_unref)
#endif

GType cs_muffin_display_config_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *cs_muffin_display_config_interface_info (void);
guint cs_muffin_display_config_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void cs_muffin_display_config_complete_get_current_state (
    CsMuffinDisplayConfig *object,
    GDBusMethodInvocation *invocation,
    guint serial,
    GVariant *monitors,
    GVariant *logical_monitors,
    GVariant *properties);



/* D-Bus signal emissions functions: */
void cs_muffin_display_config_emit_monitors_changed (
    CsMuffinDisplayConfig *object);



/* D-Bus method calls: */
void cs_muffin_display_config_call_get_current_state (
    CsMuffinDisplayConfig *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cs_muffin_display_config_call_get_current_state_finish (
    CsMuffinDisplayConfig *proxy,
    guint *out_serial,
    GVariant **out_monitors,
    GVariant **out_logical_monitors,
    GVariant **out_properties,
    GAsyncResult *res,
    GError **error);

gboolean cs_muffin_display_config_call_get_current_state_sync (
    CsMuffinDisplayConfig *proxy,
    guint *out_serial,
    GVariant **out_monitors,
    GVariant **out_logical_monitors,
    GVariant **out_properties,
    GCancellable *cancellable,
    GError **error);



/* ---- */

#define CS_TYPE_MUFFIN_DISPLAY_CONFIG_PROXY (cs_muffin_display_config_proxy_get_type ())
#define CS_MUFFIN_DISPLAY_CONFIG_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_MUFFIN_DISPLAY_CONFIG_PROXY, CsMuffinDisplayConfigProxy))
#define CS_MUFFIN_DISPLAY_CONFIG_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_MUFFIN_DISPLAY_CONFIG_PROXY, CsMuffinDisplayConfigProxyClass))
#define CS_MUFFIN_DISPLAY_CONFIG_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_MUFFIN_DISPLAY_CONFIG_PROXY, CsMuffinDisplayConfigProxyClass))
#define CS_IS_MUFFIN_DISPLAY_CONFIG_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_MUFFIN_DISPLAY_CONFIG_PROXY))
#define CS_IS_MUFFIN_DISPLAY_CONFIG_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_MUFFIN_DISPLAY_CONFIG_PROXY))

typedef struct _CsMuffinDisplayConfigProxy CsMuffinDisplayConfigProxy;
typedef struct _CsMuffinDisplayConfigProxyClass CsMuffinDisplayConfigProxyClass;
typedef struct _CsMuffinDisplayConfigProxyPrivate CsMuffinDisplayConfigProxyPrivate;

struct _CsMuffinDisplayConfigProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  CsMuffinDisplayConfigProxyPrivate *priv;
};

struct _CsMuffinDisplayConfigProxyClass
{
  GDBusProxyClass parent_class;
};

GType cs_muffin_display_config_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsMuffinDisplayConfigProxy, g_object_unref)
#endif

void cs_muffin_display_config_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsMuffinDisplayConfig *cs_muffin_display_config_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
CsMuffinDisplayConfig *cs_muffin_display_config_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void cs_muffin_display_config_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsMuffinDisplayConfig *cs_muffin_display_config_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
CsMuffinDisplayConfig *cs_muffin_display_config_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define CS_TYPE_MUFFIN_DISPLAY_CONFIG_SKELETON (cs_muffin_display_config_skeleton_get_type ())
#define CS_MUFFIN_DISPLAY_CONFIG_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_MUFFIN_DISPLAY_CONFIG_SKELETON, CsMuffinDisplayConfigSkeleton))
#define CS_MUFFIN_DISPLAY_CONFIG_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_MUFFIN_DISPLAY_CONFIG_SKELETON, CsMuffinDisplayConfigSkeletonClass))
#define CS_MUFFIN_DISPLAY_CONFIG_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_MUFFIN_DISPLAY_CONFIG_SKELETON, CsMuffinDisplayConfigSkeletonClass))
#define CS_IS_MUFFIN_DISPLAY_CONFIG_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_MUFFIN_DISPLAY_CONFIG_SKELETON))
#define CS_IS_MUFFIN_DISPLAY_CONFIG_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_MUFFIN_DISPLAY_CONFIG_SKELETON))

typedef struct _CsMuffinDisplayConfigSkeleton CsMuffinDisplayConfigSkeleton;
typedef struct _CsMuffinDisplayConfigSkeletonClass CsMuffinDisplayConfigSkeletonClass;
typedef struct _CsMuffinDisplayConfigSkeletonPrivate CsMuffinDisplayConfigSkeletonPrivate;

struct _CsMuffinDisplayConfigSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  CsMuffinDisplayConfigSkeletonPrivate *priv;
};

struct _CsMuffinDisplayConfigSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType cs_muffin_display_config_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsMuffinDisplayConfigSkeleton, g_object_unref)
#endif

CsMuffinDisplayConfig *cs_muffin_display_config_skeleton_new (void);


G_END_DECLS

#endif /* __CS_MUFFIN_DISPLAYCONFIG_PROXY_H__ */
