/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __CS_ACCOUNTS_SERVICE_PROXY_H__
#define __CS_ACCOUNTS_SERVICE_PROXY_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.freedesktop.Accounts */

#define CS_TYPE_ACCOUNTS_SERVICE (cs_accounts_service_get_type ())
#define CS_ACCOUNTS_SERVICE(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_ACCOUNTS_SERVICE, CsAccountsService))
#define CS_IS_ACCOUNTS_SERVICE(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_ACCOUNTS_SERVICE))
#define CS_ACCOUNTS_SERVICE_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), CS_TYPE_ACCOUNTS_SERVICE, CsAccountsServiceIface))

struct _CsAccountsService;
typedef struct _CsAccountsService CsAccountsService;
typedef struct _CsAccountsServiceIface CsAccountsServiceIface;

struct _CsAccountsServiceIface
{
  GTypeInterface parent_iface;

  gboolean (*handle_find_user_by_name) (
    CsAccountsService *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_name);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsAccountsService, g_object_unref)
#endif

GType cs_accounts_service_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *cs_accounts_service_interface_info (void);
guint cs_accounts_service_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void cs_accounts_service_complete_find_user_by_name (
    CsAccountsService *object,
    GDBusMethodInvocation *invocation,
    const gchar *user);



/* D-Bus method calls: */
void cs_accounts_service_call_find_user_by_name (
    CsAccountsService *proxy,
    const gchar *arg_name,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cs_accounts_service_call_find_user_by_name_finish (
    CsAccountsService *proxy,
    gchar **out_user,
    GAsyncResult *res,
    GError **error);

gboolean cs_accounts_service_call_find_user_by_name_sync (
    CsAccountsService *proxy,
    const gchar *arg_name,
    gchar **out_user,
    GCancellable *cancellable,
    GError **error);



/* ---- */

#define CS_TYPE_ACCOUNTS_SERVICE_PROXY (cs_accounts_service_proxy_get_type ())
#define CS_ACCOUNTS_SERVICE_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_ACCOUNTS_SERVICE_PROXY, CsAccountsServiceProxy))
#define CS_ACCOUNTS_SERVICE_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_ACCOUNTS_SERVICE_PROXY, CsAccountsServiceProxyClass))
#define CS_ACCOUNTS_SERVICE_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_ACCOUNTS_SERVICE_PROXY, CsAccountsServiceProxyClass))
#define CS_IS_ACCOUNTS_SERVICE_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_ACCOUNTS_SERVICE_PROXY))
#define CS_IS_ACCOUNTS_SERVICE_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_ACCOUNTS_SERVICE_PROXY))

typedef struct _CsAccountsServiceProxy CsAccountsServiceProxy;
typedef struct _CsAccountsServiceProxyClass CsAccountsServiceProxyClass;
typedef struct _CsAccountsServiceProxyPrivate CsAccountsServiceProxyPrivate;

struct _CsAccountsServiceProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  CsAccountsServiceProxyPrivate *priv;
};

struct _CsAccountsServiceProxyClass
{
  GDBusProxyClass parent_class;
};

GType cs_accounts_service_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsAccountsServiceProxy, g_object_unref)
#endif

void cs_accounts_service_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsAccountsService *cs_accounts_service_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
CsAccountsService *cs_accounts_service_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void cs_accounts_service_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsAccountsService *cs_accounts_service_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
CsAccountsService *cs_accounts_service_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define CS_TYPE_ACCOUNTS_SERVICE_SKELETON (cs_accounts_service_skeleton_get_type ())
#define CS_ACCOUNTS_SERVICE_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_ACCOUNTS_SERVICE_SKELETON, CsAccountsServiceSkeleton))
#define CS_ACCOUNTS_SERVICE_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_ACCOUNTS_SERVICE_SKELETON, CsAccountsServiceSkeletonClass))
#define CS_ACCOUNTS_SERVICE_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_ACCOUNTS_SERVICE_SKELETON, CsAccountsServiceSkeletonClass))
#define CS_IS_ACCOUNTS_SERVICE_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_ACCOUNTS_SERVICE_SKELETON))
#define CS_IS_ACCOUNTS_SERVICE_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_ACCOUNTS_SERVICE_SKELETON))

typedef struct _CsAccountsServiceSkeleton CsAccountsServiceSkeleton;
typedef struct _CsAccountsServiceSkeletonClass CsAccountsServiceSkeletonClass;
typedef struct _CsAccountsServiceSkeletonPrivate CsAccountsServiceSkeletonPrivate;

struct _CsAccountsServiceSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  CsAccountsServiceSkeletonPrivate *priv;
};

struct _CsAccountsServiceSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType cs_accounts_service_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsAccountsServiceSkeleton, g_object_unref)
#endif

CsAccountsService *cs_accounts_service_skeleton_new (void);


G_END_DECLS

#endif /* __CS_ACCOUNTS_SERVICE_PROXY_H__ */
