/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __CS_KEYBINDING_HANDLER_PROXY_H__
#define __CS_KEYBINDING_HANDLER_PROXY_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.cinnamon.SettingsDaemon.KeybindingHandler */

#define CS_TYPE_KEYBINDING_HANDLER (cs_keybinding_handler_get_type ())
#define CS_KEYBINDING_HANDLER(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_KEYBINDING_HANDLER, CsKeybindingHandler))
#define CS_IS_KEYBINDING_HANDLER(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_KEYBINDING_HANDLER))
#define CS_KEYBINDING_HANDLER_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), CS_TYPE_KEYBINDING_HANDLER, CsKeybindingHandlerIface))

struct _CsKeybindingHandler;
typedef struct _CsKeybindingHandler CsKeybindingHandler;
typedef struct _CsKeybindingHandlerIface CsKeybindingHandlerIface;

struct _CsKeybindingHandlerIface
{
  GTypeInterface parent_iface;

  gboolean (*handle_handle_keybinding) (
    CsKeybindingHandler *object,
    GDBusMethodInvocation *invocation,
    guint arg_type);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsKeybindingHandler, g_object_unref)
#endif

GType cs_keybinding_handler_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *cs_keybinding_handler_interface_info (void);
guint cs_keybinding_handler_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void cs_keybinding_handler_complete_handle_keybinding (
    CsKeybindingHandler *object,
    GDBusMethodInvocation *invocation);



/* D-Bus method calls: */
void cs_keybinding_handler_call_handle_keybinding (
    CsKeybindingHandler *proxy,
    guint arg_type,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cs_keybinding_handler_call_handle_keybinding_finish (
    CsKeybindingHandler *proxy,
    GAsyncResult *res,
    GError **error);

gboolean cs_keybinding_handler_call_handle_keybinding_sync (
    CsKeybindingHandler *proxy,
    guint arg_type,
    GCancellable *cancellable,
    GError **error);



/* ---- */

#define CS_TYPE_KEYBINDING_HANDLER_PROXY (cs_keybinding_handler_proxy_get_type ())
#define CS_KEYBINDING_HANDLER_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_KEYBINDING_HANDLER_PROXY, CsKeybindingHandlerProxy))
#define CS_KEYBINDING_HANDLER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_KEYBINDING_HANDLER_PROXY, CsKeybindingHandlerProxyClass))
#define CS_KEYBINDING_HANDLER_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_KEYBINDING_HANDLER_PROXY, CsKeybindingHandlerProxyClass))
#define CS_IS_KEYBINDING_HANDLER_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_KEYBINDING_HANDLER_PROXY))
#define CS_IS_KEYBINDING_HANDLER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_KEYBINDING_HANDLER_PROXY))

typedef struct _CsKeybindingHandlerProxy CsKeybindingHandlerProxy;
typedef struct _CsKeybindingHandlerProxyClass CsKeybindingHandlerProxyClass;
typedef struct _CsKeybindingHandlerProxyPrivate CsKeybindingHandlerProxyPrivate;

struct _CsKeybindingHandlerProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  CsKeybindingHandlerProxyPrivate *priv;
};

struct _CsKeybindingHandlerProxyClass
{
  GDBusProxyClass parent_class;
};

GType cs_keybinding_handler_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsKeybindingHandlerProxy, g_object_unref)
#endif

void cs_keybinding_handler_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsKeybindingHandler *cs_keybinding_handler_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
CsKeybindingHandler *cs_keybinding_handler_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void cs_keybinding_handler_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsKeybindingHandler *cs_keybinding_handler_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
CsKeybindingHandler *cs_keybinding_handler_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define CS_TYPE_KEYBINDING_HANDLER_SKELETON (cs_keybinding_handler_skeleton_get_type ())
#define CS_KEYBINDING_HANDLER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_KEYBINDING_HANDLER_SKELETON, CsKeybindingHandlerSkeleton))
#define CS_KEYBINDING_HANDLER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_KEYBINDING_HANDLER_SKELETON, CsKeybindingHandlerSkeletonClass))
#define CS_KEYBINDING_HANDLER_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_KEYBINDING_HANDLER_SKELETON, CsKeybindingHandlerSkeletonClass))
#define CS_IS_KEYBINDING_HANDLER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_KEYBINDING_HANDLER_SKELETON))
#define CS_IS_KEYBINDING_HANDLER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_KEYBINDING_HANDLER_SKELETON))

typedef struct _CsKeybindingHandlerSkeleton CsKeybindingHandlerSkeleton;
typedef struct _CsKeybindingHandlerSkeletonClass CsKeybindingHandlerSkeletonClass;
typedef struct _CsKeybindingHandlerSkeletonPrivate CsKeybindingHandlerSkeletonPrivate;

struct _CsKeybindingHandlerSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  CsKeybindingHandlerSkeletonPrivate *priv;
};

struct _CsKeybindingHandlerSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType cs_keybinding_handler_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsKeybindingHandlerSkeleton, g_object_unref)
#endif

CsKeybindingHandler *cs_keybinding_handler_skeleton_new (void);


G_END_DECLS

#endif /* __CS_KEYBINDING_HANDLER_PROXY_H__ */
