/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __CS_SESSION_PRESENCE_PROXY_H__
#define __CS_SESSION_PRESENCE_PROXY_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.gnome.SessionManager.Presence */

#define CS_TYPE_SESSION_PRESENCE (cs_session_presence_get_type ())
#define CS_SESSION_PRESENCE(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_SESSION_PRESENCE, CsSessionPresence))
#define CS_IS_SESSION_PRESENCE(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_SESSION_PRESENCE))
#define CS_SESSION_PRESENCE_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), CS_TYPE_SESSION_PRESENCE, CsSessionPresenceIface))

struct _CsSessionPresence;
typedef struct _CsSessionPresence CsSessionPresence;
typedef struct _CsSessionPresenceIface CsSessionPresenceIface;

struct _CsSessionPresenceIface
{
  GTypeInterface parent_iface;


  guint  (*get_status) (CsSessionPresence *object);

  void (*status_changed) (
    CsSessionPresence *object,
    guint arg_status);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsSessionPresence, g_object_unref)
#endif

GType cs_session_presence_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *cs_session_presence_interface_info (void);
guint cs_session_presence_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus signal emissions functions: */
void cs_session_presence_emit_status_changed (
    CsSessionPresence *object,
    guint arg_status);



/* D-Bus property accessors: */
guint cs_session_presence_get_status (CsSessionPresence *object);
void cs_session_presence_set_status (CsSessionPresence *object, guint value);


/* ---- */

#define CS_TYPE_SESSION_PRESENCE_PROXY (cs_session_presence_proxy_get_type ())
#define CS_SESSION_PRESENCE_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_SESSION_PRESENCE_PROXY, CsSessionPresenceProxy))
#define CS_SESSION_PRESENCE_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_SESSION_PRESENCE_PROXY, CsSessionPresenceProxyClass))
#define CS_SESSION_PRESENCE_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_SESSION_PRESENCE_PROXY, CsSessionPresenceProxyClass))
#define CS_IS_SESSION_PRESENCE_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_SESSION_PRESENCE_PROXY))
#define CS_IS_SESSION_PRESENCE_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_SESSION_PRESENCE_PROXY))

typedef struct _CsSessionPresenceProxy CsSessionPresenceProxy;
typedef struct _CsSessionPresenceProxyClass CsSessionPresenceProxyClass;
typedef struct _CsSessionPresenceProxyPrivate CsSessionPresenceProxyPrivate;

struct _CsSessionPresenceProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  CsSessionPresenceProxyPrivate *priv;
};

struct _CsSessionPresenceProxyClass
{
  GDBusProxyClass parent_class;
};

GType cs_session_presence_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsSessionPresenceProxy, g_object_unref)
#endif

void cs_session_presence_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsSessionPresence *cs_session_presence_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
CsSessionPresence *cs_session_presence_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void cs_session_presence_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsSessionPresence *cs_session_presence_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
CsSessionPresence *cs_session_presence_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define CS_TYPE_SESSION_PRESENCE_SKELETON (cs_session_presence_skeleton_get_type ())
#define CS_SESSION_PRESENCE_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_SESSION_PRESENCE_SKELETON, CsSessionPresenceSkeleton))
#define CS_SESSION_PRESENCE_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_SESSION_PRESENCE_SKELETON, CsSessionPresenceSkeletonClass))
#define CS_SESSION_PRESENCE_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_SESSION_PRESENCE_SKELETON, CsSessionPresenceSkeletonClass))
#define CS_IS_SESSION_PRESENCE_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_SESSION_PRESENCE_SKELETON))
#define CS_IS_SESSION_PRESENCE_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_SESSION_PRESENCE_SKELETON))

typedef struct _CsSessionPresenceSkeleton CsSessionPresenceSkeleton;
typedef struct _CsSessionPresenceSkeletonClass CsSessionPresenceSkeletonClass;
typedef struct _CsSessionPresenceSkeletonPrivate CsSessionPresenceSkeletonPrivate;

struct _CsSessionPresenceSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  CsSessionPresenceSkeletonPrivate *priv;
};

struct _CsSessionPresenceSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType cs_session_presence_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsSessionPresenceSkeleton, g_object_unref)
#endif

CsSessionPresence *cs_session_presence_skeleton_new (void);


G_END_DECLS

#endif /* __CS_SESSION_PRESENCE_PROXY_H__ */
