/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __CS_LOGIN_MANAGER_PROXY_H__
#define __CS_LOGIN_MANAGER_PROXY_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.freedesktop.login1.Manager */

#define CS_TYPE_LOGIND_MANAGER (cs_logind_manager_get_type ())
#define CS_LOGIND_MANAGER(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_LOGIND_MANAGER, CsLogindManager))
#define CS_IS_LOGIND_MANAGER(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_LOGIND_MANAGER))
#define CS_LOGIND_MANAGER_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), CS_TYPE_LOGIND_MANAGER, CsLogindManagerIface))

struct _CsLogindManager;
typedef struct _CsLogindManager CsLogindManager;
typedef struct _CsLogindManagerIface CsLogindManagerIface;

struct _CsLogindManagerIface
{
  GTypeInterface parent_iface;

  gboolean (*handle_get_session) (
    CsLogindManager *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_session_id);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsLogindManager, g_object_unref)
#endif

GType cs_logind_manager_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *cs_logind_manager_interface_info (void);
guint cs_logind_manager_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void cs_logind_manager_complete_get_session (
    CsLogindManager *object,
    GDBusMethodInvocation *invocation,
    const gchar *object_path);



/* D-Bus method calls: */
void cs_logind_manager_call_get_session (
    CsLogindManager *proxy,
    const gchar *arg_session_id,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cs_logind_manager_call_get_session_finish (
    CsLogindManager *proxy,
    gchar **out_object_path,
    GAsyncResult *res,
    GError **error);

gboolean cs_logind_manager_call_get_session_sync (
    CsLogindManager *proxy,
    const gchar *arg_session_id,
    gchar **out_object_path,
    GCancellable *cancellable,
    GError **error);



/* ---- */

#define CS_TYPE_LOGIND_MANAGER_PROXY (cs_logind_manager_proxy_get_type ())
#define CS_LOGIND_MANAGER_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_LOGIND_MANAGER_PROXY, CsLogindManagerProxy))
#define CS_LOGIND_MANAGER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_LOGIND_MANAGER_PROXY, CsLogindManagerProxyClass))
#define CS_LOGIND_MANAGER_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_LOGIND_MANAGER_PROXY, CsLogindManagerProxyClass))
#define CS_IS_LOGIND_MANAGER_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_LOGIND_MANAGER_PROXY))
#define CS_IS_LOGIND_MANAGER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_LOGIND_MANAGER_PROXY))

typedef struct _CsLogindManagerProxy CsLogindManagerProxy;
typedef struct _CsLogindManagerProxyClass CsLogindManagerProxyClass;
typedef struct _CsLogindManagerProxyPrivate CsLogindManagerProxyPrivate;

struct _CsLogindManagerProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  CsLogindManagerProxyPrivate *priv;
};

struct _CsLogindManagerProxyClass
{
  GDBusProxyClass parent_class;
};

GType cs_logind_manager_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsLogindManagerProxy, g_object_unref)
#endif

void cs_logind_manager_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsLogindManager *cs_logind_manager_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
CsLogindManager *cs_logind_manager_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void cs_logind_manager_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsLogindManager *cs_logind_manager_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
CsLogindManager *cs_logind_manager_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define CS_TYPE_LOGIND_MANAGER_SKELETON (cs_logind_manager_skeleton_get_type ())
#define CS_LOGIND_MANAGER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_LOGIND_MANAGER_SKELETON, CsLogindManagerSkeleton))
#define CS_LOGIND_MANAGER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_LOGIND_MANAGER_SKELETON, CsLogindManagerSkeletonClass))
#define CS_LOGIND_MANAGER_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_LOGIND_MANAGER_SKELETON, CsLogindManagerSkeletonClass))
#define CS_IS_LOGIND_MANAGER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_LOGIND_MANAGER_SKELETON))
#define CS_IS_LOGIND_MANAGER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_LOGIND_MANAGER_SKELETON))

typedef struct _CsLogindManagerSkeleton CsLogindManagerSkeleton;
typedef struct _CsLogindManagerSkeletonClass CsLogindManagerSkeletonClass;
typedef struct _CsLogindManagerSkeletonPrivate CsLogindManagerSkeletonPrivate;

struct _CsLogindManagerSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  CsLogindManagerSkeletonPrivate *priv;
};

struct _CsLogindManagerSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType cs_logind_manager_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsLogindManagerSkeleton, g_object_unref)
#endif

CsLogindManager *cs_logind_manager_skeleton_new (void);


G_END_DECLS

#endif /* __CS_LOGIN_MANAGER_PROXY_H__ */
