/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __CS_UPOWER_PROXY_H__
#define __CS_UPOWER_PROXY_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.freedesktop.UPower */

#define CS_TYPE_UPOWER (cs_upower_get_type ())
#define CS_UPOWER(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_UPOWER, CsUPower))
#define CS_IS_UPOWER(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_UPOWER))
#define CS_UPOWER_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), CS_TYPE_UPOWER, CsUPowerIface))

struct _CsUPower;
typedef struct _CsUPower CsUPower;
typedef struct _CsUPowerIface CsUPowerIface;

struct _CsUPowerIface
{
  GTypeInterface parent_iface;



  gboolean (*handle_enumerate_devices) (
    CsUPower *object,
    GDBusMethodInvocation *invocation);

  gboolean  (*get_on_battery) (CsUPower *object);

  void (*device_added) (
    CsUPower *object,
    const gchar *arg_device);

  void (*device_removed) (
    CsUPower *object,
    const gchar *arg_device);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsUPower, g_object_unref)
#endif

GType cs_upower_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *cs_upower_interface_info (void);
guint cs_upower_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void cs_upower_complete_enumerate_devices (
    CsUPower *object,
    GDBusMethodInvocation *invocation,
    GVariant *devices);



/* D-Bus signal emissions functions: */
void cs_upower_emit_device_added (
    CsUPower *object,
    const gchar *arg_device);

void cs_upower_emit_device_removed (
    CsUPower *object,
    const gchar *arg_device);



/* D-Bus method calls: */
void cs_upower_call_enumerate_devices (
    CsUPower *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cs_upower_call_enumerate_devices_finish (
    CsUPower *proxy,
    GVariant **out_devices,
    GAsyncResult *res,
    GError **error);

gboolean cs_upower_call_enumerate_devices_sync (
    CsUPower *proxy,
    GVariant **out_devices,
    GCancellable *cancellable,
    GError **error);



/* D-Bus property accessors: */
gboolean cs_upower_get_on_battery (CsUPower *object);
void cs_upower_set_on_battery (CsUPower *object, gboolean value);


/* ---- */

#define CS_TYPE_UPOWER_PROXY (cs_upower_proxy_get_type ())
#define CS_UPOWER_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_UPOWER_PROXY, CsUPowerProxy))
#define CS_UPOWER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_UPOWER_PROXY, CsUPowerProxyClass))
#define CS_UPOWER_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_UPOWER_PROXY, CsUPowerProxyClass))
#define CS_IS_UPOWER_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_UPOWER_PROXY))
#define CS_IS_UPOWER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_UPOWER_PROXY))

typedef struct _CsUPowerProxy CsUPowerProxy;
typedef struct _CsUPowerProxyClass CsUPowerProxyClass;
typedef struct _CsUPowerProxyPrivate CsUPowerProxyPrivate;

struct _CsUPowerProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  CsUPowerProxyPrivate *priv;
};

struct _CsUPowerProxyClass
{
  GDBusProxyClass parent_class;
};

GType cs_upower_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsUPowerProxy, g_object_unref)
#endif

void cs_upower_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsUPower *cs_upower_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
CsUPower *cs_upower_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void cs_upower_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsUPower *cs_upower_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
CsUPower *cs_upower_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define CS_TYPE_UPOWER_SKELETON (cs_upower_skeleton_get_type ())
#define CS_UPOWER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_UPOWER_SKELETON, CsUPowerSkeleton))
#define CS_UPOWER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_UPOWER_SKELETON, CsUPowerSkeletonClass))
#define CS_UPOWER_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_UPOWER_SKELETON, CsUPowerSkeletonClass))
#define CS_IS_UPOWER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_UPOWER_SKELETON))
#define CS_IS_UPOWER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_UPOWER_SKELETON))

typedef struct _CsUPowerSkeleton CsUPowerSkeleton;
typedef struct _CsUPowerSkeletonClass CsUPowerSkeletonClass;
typedef struct _CsUPowerSkeletonPrivate CsUPowerSkeletonPrivate;

struct _CsUPowerSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  CsUPowerSkeletonPrivate *priv;
};

struct _CsUPowerSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType cs_upower_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsUPowerSkeleton, g_object_unref)
#endif

CsUPower *cs_upower_skeleton_new (void);


G_END_DECLS

#endif /* __CS_UPOWER_PROXY_H__ */
