/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __CS_CONSOLEKIT_SESSION_PROXY_H__
#define __CS_CONSOLEKIT_SESSION_PROXY_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.freedesktop.ConsoleKit.Session */

#define CS_TYPE_CONSOLE_KIT_SESSION (cs_console_kit_session_get_type ())
#define CS_CONSOLE_KIT_SESSION(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_CONSOLE_KIT_SESSION, CsConsoleKitSession))
#define CS_IS_CONSOLE_KIT_SESSION(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_CONSOLE_KIT_SESSION))
#define CS_CONSOLE_KIT_SESSION_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), CS_TYPE_CONSOLE_KIT_SESSION, CsConsoleKitSessionIface))

struct _CsConsoleKitSession;
typedef struct _CsConsoleKitSession CsConsoleKitSession;
typedef struct _CsConsoleKitSessionIface CsConsoleKitSessionIface;

struct _CsConsoleKitSessionIface
{
  GTypeInterface parent_iface;


  gboolean (*handle_lock) (
    CsConsoleKitSession *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_unlock) (
    CsConsoleKitSession *object,
    GDBusMethodInvocation *invocation);

  void (*active_changed) (
    CsConsoleKitSession *object,
    gboolean arg_is_active);

  void (*lock) (
    CsConsoleKitSession *object);

  void (*unlock) (
    CsConsoleKitSession *object);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsConsoleKitSession, g_object_unref)
#endif

GType cs_console_kit_session_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *cs_console_kit_session_interface_info (void);
guint cs_console_kit_session_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void cs_console_kit_session_complete_lock (
    CsConsoleKitSession *object,
    GDBusMethodInvocation *invocation);

void cs_console_kit_session_complete_unlock (
    CsConsoleKitSession *object,
    GDBusMethodInvocation *invocation);



/* D-Bus signal emissions functions: */
void cs_console_kit_session_emit_active_changed (
    CsConsoleKitSession *object,
    gboolean arg_is_active);

void cs_console_kit_session_emit_lock (
    CsConsoleKitSession *object);

void cs_console_kit_session_emit_unlock (
    CsConsoleKitSession *object);



/* D-Bus method calls: */
void cs_console_kit_session_call_lock (
    CsConsoleKitSession *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cs_console_kit_session_call_lock_finish (
    CsConsoleKitSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean cs_console_kit_session_call_lock_sync (
    CsConsoleKitSession *proxy,
    GCancellable *cancellable,
    GError **error);

void cs_console_kit_session_call_unlock (
    CsConsoleKitSession *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cs_console_kit_session_call_unlock_finish (
    CsConsoleKitSession *proxy,
    GAsyncResult *res,
    GError **error);

gboolean cs_console_kit_session_call_unlock_sync (
    CsConsoleKitSession *proxy,
    GCancellable *cancellable,
    GError **error);



/* ---- */

#define CS_TYPE_CONSOLE_KIT_SESSION_PROXY (cs_console_kit_session_proxy_get_type ())
#define CS_CONSOLE_KIT_SESSION_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_CONSOLE_KIT_SESSION_PROXY, CsConsoleKitSessionProxy))
#define CS_CONSOLE_KIT_SESSION_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_CONSOLE_KIT_SESSION_PROXY, CsConsoleKitSessionProxyClass))
#define CS_CONSOLE_KIT_SESSION_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_CONSOLE_KIT_SESSION_PROXY, CsConsoleKitSessionProxyClass))
#define CS_IS_CONSOLE_KIT_SESSION_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_CONSOLE_KIT_SESSION_PROXY))
#define CS_IS_CONSOLE_KIT_SESSION_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_CONSOLE_KIT_SESSION_PROXY))

typedef struct _CsConsoleKitSessionProxy CsConsoleKitSessionProxy;
typedef struct _CsConsoleKitSessionProxyClass CsConsoleKitSessionProxyClass;
typedef struct _CsConsoleKitSessionProxyPrivate CsConsoleKitSessionProxyPrivate;

struct _CsConsoleKitSessionProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  CsConsoleKitSessionProxyPrivate *priv;
};

struct _CsConsoleKitSessionProxyClass
{
  GDBusProxyClass parent_class;
};

GType cs_console_kit_session_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsConsoleKitSessionProxy, g_object_unref)
#endif

void cs_console_kit_session_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsConsoleKitSession *cs_console_kit_session_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
CsConsoleKitSession *cs_console_kit_session_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void cs_console_kit_session_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsConsoleKitSession *cs_console_kit_session_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
CsConsoleKitSession *cs_console_kit_session_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define CS_TYPE_CONSOLE_KIT_SESSION_SKELETON (cs_console_kit_session_skeleton_get_type ())
#define CS_CONSOLE_KIT_SESSION_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_CONSOLE_KIT_SESSION_SKELETON, CsConsoleKitSessionSkeleton))
#define CS_CONSOLE_KIT_SESSION_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_CONSOLE_KIT_SESSION_SKELETON, CsConsoleKitSessionSkeletonClass))
#define CS_CONSOLE_KIT_SESSION_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_CONSOLE_KIT_SESSION_SKELETON, CsConsoleKitSessionSkeletonClass))
#define CS_IS_CONSOLE_KIT_SESSION_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_CONSOLE_KIT_SESSION_SKELETON))
#define CS_IS_CONSOLE_KIT_SESSION_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_CONSOLE_KIT_SESSION_SKELETON))

typedef struct _CsConsoleKitSessionSkeleton CsConsoleKitSessionSkeleton;
typedef struct _CsConsoleKitSessionSkeletonClass CsConsoleKitSessionSkeletonClass;
typedef struct _CsConsoleKitSessionSkeletonPrivate CsConsoleKitSessionSkeletonPrivate;

struct _CsConsoleKitSessionSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  CsConsoleKitSessionSkeletonPrivate *priv;
};

struct _CsConsoleKitSessionSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType cs_console_kit_session_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsConsoleKitSessionSkeleton, g_object_unref)
#endif

CsConsoleKitSession *cs_console_kit_session_skeleton_new (void);


G_END_DECLS

#endif /* __CS_CONSOLEKIT_SESSION_PROXY_H__ */
