/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __CS_CONSOLEKIT_MANAGER_PROXY_H__
#define __CS_CONSOLEKIT_MANAGER_PROXY_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.freedesktop.ConsoleKit.Manager */

#define CS_TYPE_CONSOLE_KIT_MANAGER (cs_console_kit_manager_get_type ())
#define CS_CONSOLE_KIT_MANAGER(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_CONSOLE_KIT_MANAGER, CsConsoleKitManager))
#define CS_IS_CONSOLE_KIT_MANAGER(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_CONSOLE_KIT_MANAGER))
#define CS_CONSOLE_KIT_MANAGER_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), CS_TYPE_CONSOLE_KIT_MANAGER, CsConsoleKitManagerIface))

struct _CsConsoleKitManager;
typedef struct _CsConsoleKitManager CsConsoleKitManager;
typedef struct _CsConsoleKitManagerIface CsConsoleKitManagerIface;

struct _CsConsoleKitManagerIface
{
  GTypeInterface parent_iface;

  gboolean (*handle_get_current_session) (
    CsConsoleKitManager *object,
    GDBusMethodInvocation *invocation);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsConsoleKitManager, g_object_unref)
#endif

GType cs_console_kit_manager_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *cs_console_kit_manager_interface_info (void);
guint cs_console_kit_manager_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void cs_console_kit_manager_complete_get_current_session (
    CsConsoleKitManager *object,
    GDBusMethodInvocation *invocation,
    const gchar *ssid);



/* D-Bus method calls: */
void cs_console_kit_manager_call_get_current_session (
    CsConsoleKitManager *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cs_console_kit_manager_call_get_current_session_finish (
    CsConsoleKitManager *proxy,
    gchar **out_ssid,
    GAsyncResult *res,
    GError **error);

gboolean cs_console_kit_manager_call_get_current_session_sync (
    CsConsoleKitManager *proxy,
    gchar **out_ssid,
    GCancellable *cancellable,
    GError **error);



/* ---- */

#define CS_TYPE_CONSOLE_KIT_MANAGER_PROXY (cs_console_kit_manager_proxy_get_type ())
#define CS_CONSOLE_KIT_MANAGER_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_CONSOLE_KIT_MANAGER_PROXY, CsConsoleKitManagerProxy))
#define CS_CONSOLE_KIT_MANAGER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_CONSOLE_KIT_MANAGER_PROXY, CsConsoleKitManagerProxyClass))
#define CS_CONSOLE_KIT_MANAGER_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_CONSOLE_KIT_MANAGER_PROXY, CsConsoleKitManagerProxyClass))
#define CS_IS_CONSOLE_KIT_MANAGER_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_CONSOLE_KIT_MANAGER_PROXY))
#define CS_IS_CONSOLE_KIT_MANAGER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_CONSOLE_KIT_MANAGER_PROXY))

typedef struct _CsConsoleKitManagerProxy CsConsoleKitManagerProxy;
typedef struct _CsConsoleKitManagerProxyClass CsConsoleKitManagerProxyClass;
typedef struct _CsConsoleKitManagerProxyPrivate CsConsoleKitManagerProxyPrivate;

struct _CsConsoleKitManagerProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  CsConsoleKitManagerProxyPrivate *priv;
};

struct _CsConsoleKitManagerProxyClass
{
  GDBusProxyClass parent_class;
};

GType cs_console_kit_manager_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsConsoleKitManagerProxy, g_object_unref)
#endif

void cs_console_kit_manager_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsConsoleKitManager *cs_console_kit_manager_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
CsConsoleKitManager *cs_console_kit_manager_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void cs_console_kit_manager_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsConsoleKitManager *cs_console_kit_manager_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
CsConsoleKitManager *cs_console_kit_manager_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define CS_TYPE_CONSOLE_KIT_MANAGER_SKELETON (cs_console_kit_manager_skeleton_get_type ())
#define CS_CONSOLE_KIT_MANAGER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_CONSOLE_KIT_MANAGER_SKELETON, CsConsoleKitManagerSkeleton))
#define CS_CONSOLE_KIT_MANAGER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_CONSOLE_KIT_MANAGER_SKELETON, CsConsoleKitManagerSkeletonClass))
#define CS_CONSOLE_KIT_MANAGER_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_CONSOLE_KIT_MANAGER_SKELETON, CsConsoleKitManagerSkeletonClass))
#define CS_IS_CONSOLE_KIT_MANAGER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_CONSOLE_KIT_MANAGER_SKELETON))
#define CS_IS_CONSOLE_KIT_MANAGER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_CONSOLE_KIT_MANAGER_SKELETON))

typedef struct _CsConsoleKitManagerSkeleton CsConsoleKitManagerSkeleton;
typedef struct _CsConsoleKitManagerSkeletonClass CsConsoleKitManagerSkeletonClass;
typedef struct _CsConsoleKitManagerSkeletonPrivate CsConsoleKitManagerSkeletonPrivate;

struct _CsConsoleKitManagerSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  CsConsoleKitManagerSkeletonPrivate *priv;
};

struct _CsConsoleKitManagerSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType cs_console_kit_manager_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsConsoleKitManagerSkeleton, g_object_unref)
#endif

CsConsoleKitManager *cs_console_kit_manager_skeleton_new (void);


G_END_DECLS

#endif /* __CS_CONSOLEKIT_MANAGER_PROXY_H__ */
