/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __CS_ACCOUNTS_USER_PROXY_H__
#define __CS_ACCOUNTS_USER_PROXY_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.freedesktop.Accounts.User */

#define CS_TYPE_ACCOUNTS_USER (cs_accounts_user_get_type ())
#define CS_ACCOUNTS_USER(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_ACCOUNTS_USER, CsAccountsUser))
#define CS_IS_ACCOUNTS_USER(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_ACCOUNTS_USER))
#define CS_ACCOUNTS_USER_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), CS_TYPE_ACCOUNTS_USER, CsAccountsUserIface))

struct _CsAccountsUser;
typedef struct _CsAccountsUser CsAccountsUser;
typedef struct _CsAccountsUserIface CsAccountsUserIface;

struct _CsAccountsUserIface
{
  GTypeInterface parent_iface;

  const gchar * (*get_home_directory) (CsAccountsUser *object);

  const gchar * (*get_icon_file) (CsAccountsUser *object);

  const gchar * (*get_real_name) (CsAccountsUser *object);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsAccountsUser, g_object_unref)
#endif

GType cs_accounts_user_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *cs_accounts_user_interface_info (void);
guint cs_accounts_user_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus property accessors: */
const gchar *cs_accounts_user_get_real_name (CsAccountsUser *object);
gchar *cs_accounts_user_dup_real_name (CsAccountsUser *object);
void cs_accounts_user_set_real_name (CsAccountsUser *object, const gchar *value);

const gchar *cs_accounts_user_get_icon_file (CsAccountsUser *object);
gchar *cs_accounts_user_dup_icon_file (CsAccountsUser *object);
void cs_accounts_user_set_icon_file (CsAccountsUser *object, const gchar *value);

const gchar *cs_accounts_user_get_home_directory (CsAccountsUser *object);
gchar *cs_accounts_user_dup_home_directory (CsAccountsUser *object);
void cs_accounts_user_set_home_directory (CsAccountsUser *object, const gchar *value);


/* ---- */

#define CS_TYPE_ACCOUNTS_USER_PROXY (cs_accounts_user_proxy_get_type ())
#define CS_ACCOUNTS_USER_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_ACCOUNTS_USER_PROXY, CsAccountsUserProxy))
#define CS_ACCOUNTS_USER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_ACCOUNTS_USER_PROXY, CsAccountsUserProxyClass))
#define CS_ACCOUNTS_USER_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_ACCOUNTS_USER_PROXY, CsAccountsUserProxyClass))
#define CS_IS_ACCOUNTS_USER_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_ACCOUNTS_USER_PROXY))
#define CS_IS_ACCOUNTS_USER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_ACCOUNTS_USER_PROXY))

typedef struct _CsAccountsUserProxy CsAccountsUserProxy;
typedef struct _CsAccountsUserProxyClass CsAccountsUserProxyClass;
typedef struct _CsAccountsUserProxyPrivate CsAccountsUserProxyPrivate;

struct _CsAccountsUserProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  CsAccountsUserProxyPrivate *priv;
};

struct _CsAccountsUserProxyClass
{
  GDBusProxyClass parent_class;
};

GType cs_accounts_user_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsAccountsUserProxy, g_object_unref)
#endif

void cs_accounts_user_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsAccountsUser *cs_accounts_user_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
CsAccountsUser *cs_accounts_user_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void cs_accounts_user_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsAccountsUser *cs_accounts_user_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
CsAccountsUser *cs_accounts_user_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define CS_TYPE_ACCOUNTS_USER_SKELETON (cs_accounts_user_skeleton_get_type ())
#define CS_ACCOUNTS_USER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_ACCOUNTS_USER_SKELETON, CsAccountsUserSkeleton))
#define CS_ACCOUNTS_USER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_ACCOUNTS_USER_SKELETON, CsAccountsUserSkeletonClass))
#define CS_ACCOUNTS_USER_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_ACCOUNTS_USER_SKELETON, CsAccountsUserSkeletonClass))
#define CS_IS_ACCOUNTS_USER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_ACCOUNTS_USER_SKELETON))
#define CS_IS_ACCOUNTS_USER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_ACCOUNTS_USER_SKELETON))

typedef struct _CsAccountsUserSkeleton CsAccountsUserSkeleton;
typedef struct _CsAccountsUserSkeletonClass CsAccountsUserSkeletonClass;
typedef struct _CsAccountsUserSkeletonPrivate CsAccountsUserSkeletonPrivate;

struct _CsAccountsUserSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  CsAccountsUserSkeletonPrivate *priv;
};

struct _CsAccountsUserSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType cs_accounts_user_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsAccountsUserSkeleton, g_object_unref)
#endif

CsAccountsUser *cs_accounts_user_skeleton_new (void);


G_END_DECLS

#endif /* __CS_ACCOUNTS_USER_PROXY_H__ */
