/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __CS_SCREENSAVER_PROXY_H__
#define __CS_SCREENSAVER_PROXY_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.cinnamon.ScreenSaver */

#define CS_TYPE_SCREEN_SAVER (cs_screen_saver_get_type ())
#define CS_SCREEN_SAVER(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_SCREEN_SAVER, CsScreenSaver))
#define CS_IS_SCREEN_SAVER(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_SCREEN_SAVER))
#define CS_SCREEN_SAVER_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), CS_TYPE_SCREEN_SAVER, CsScreenSaverIface))

struct _CsScreenSaver;
typedef struct _CsScreenSaver CsScreenSaver;
typedef struct _CsScreenSaverIface CsScreenSaverIface;

struct _CsScreenSaverIface
{
  GTypeInterface parent_iface;


  gboolean (*handle_get_active) (
    CsScreenSaver *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_get_active_time) (
    CsScreenSaver *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_get_session_idle_time) (
    CsScreenSaver *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_lock) (
    CsScreenSaver *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_message);

  gboolean (*handle_quit) (
    CsScreenSaver *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_set_active) (
    CsScreenSaver *object,
    GDBusMethodInvocation *invocation,
    gboolean arg_e);

  gboolean (*handle_simulate_user_activity) (
    CsScreenSaver *object,
    GDBusMethodInvocation *invocation);

  void (*active_changed) (
    CsScreenSaver *object,
    gboolean arg_arg_0);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsScreenSaver, g_object_unref)
#endif

GType cs_screen_saver_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *cs_screen_saver_interface_info (void);
guint cs_screen_saver_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void cs_screen_saver_complete_lock (
    CsScreenSaver *object,
    GDBusMethodInvocation *invocation);

void cs_screen_saver_complete_simulate_user_activity (
    CsScreenSaver *object,
    GDBusMethodInvocation *invocation);

void cs_screen_saver_complete_get_active (
    CsScreenSaver *object,
    GDBusMethodInvocation *invocation,
    gboolean arg_0);

void cs_screen_saver_complete_get_active_time (
    CsScreenSaver *object,
    GDBusMethodInvocation *invocation,
    guint seconds);

void cs_screen_saver_complete_get_session_idle_time (
    CsScreenSaver *object,
    GDBusMethodInvocation *invocation,
    guint seconds);

void cs_screen_saver_complete_set_active (
    CsScreenSaver *object,
    GDBusMethodInvocation *invocation);

void cs_screen_saver_complete_quit (
    CsScreenSaver *object,
    GDBusMethodInvocation *invocation);



/* D-Bus signal emissions functions: */
void cs_screen_saver_emit_active_changed (
    CsScreenSaver *object,
    gboolean arg_arg_0);



/* D-Bus method calls: */
void cs_screen_saver_call_lock (
    CsScreenSaver *proxy,
    const gchar *arg_message,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cs_screen_saver_call_lock_finish (
    CsScreenSaver *proxy,
    GAsyncResult *res,
    GError **error);

gboolean cs_screen_saver_call_lock_sync (
    CsScreenSaver *proxy,
    const gchar *arg_message,
    GCancellable *cancellable,
    GError **error);

void cs_screen_saver_call_simulate_user_activity (
    CsScreenSaver *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cs_screen_saver_call_simulate_user_activity_finish (
    CsScreenSaver *proxy,
    GAsyncResult *res,
    GError **error);

gboolean cs_screen_saver_call_simulate_user_activity_sync (
    CsScreenSaver *proxy,
    GCancellable *cancellable,
    GError **error);

void cs_screen_saver_call_get_active (
    CsScreenSaver *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cs_screen_saver_call_get_active_finish (
    CsScreenSaver *proxy,
    gboolean *out_arg_0,
    GAsyncResult *res,
    GError **error);

gboolean cs_screen_saver_call_get_active_sync (
    CsScreenSaver *proxy,
    gboolean *out_arg_0,
    GCancellable *cancellable,
    GError **error);

void cs_screen_saver_call_get_active_time (
    CsScreenSaver *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cs_screen_saver_call_get_active_time_finish (
    CsScreenSaver *proxy,
    guint *out_seconds,
    GAsyncResult *res,
    GError **error);

gboolean cs_screen_saver_call_get_active_time_sync (
    CsScreenSaver *proxy,
    guint *out_seconds,
    GCancellable *cancellable,
    GError **error);

void cs_screen_saver_call_get_session_idle_time (
    CsScreenSaver *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cs_screen_saver_call_get_session_idle_time_finish (
    CsScreenSaver *proxy,
    guint *out_seconds,
    GAsyncResult *res,
    GError **error);

gboolean cs_screen_saver_call_get_session_idle_time_sync (
    CsScreenSaver *proxy,
    guint *out_seconds,
    GCancellable *cancellable,
    GError **error);

void cs_screen_saver_call_set_active (
    CsScreenSaver *proxy,
    gboolean arg_e,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cs_screen_saver_call_set_active_finish (
    CsScreenSaver *proxy,
    GAsyncResult *res,
    GError **error);

gboolean cs_screen_saver_call_set_active_sync (
    CsScreenSaver *proxy,
    gboolean arg_e,
    GCancellable *cancellable,
    GError **error);

void cs_screen_saver_call_quit (
    CsScreenSaver *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cs_screen_saver_call_quit_finish (
    CsScreenSaver *proxy,
    GAsyncResult *res,
    GError **error);

gboolean cs_screen_saver_call_quit_sync (
    CsScreenSaver *proxy,
    GCancellable *cancellable,
    GError **error);



/* ---- */

#define CS_TYPE_SCREEN_SAVER_PROXY (cs_screen_saver_proxy_get_type ())
#define CS_SCREEN_SAVER_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_SCREEN_SAVER_PROXY, CsScreenSaverProxy))
#define CS_SCREEN_SAVER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_SCREEN_SAVER_PROXY, CsScreenSaverProxyClass))
#define CS_SCREEN_SAVER_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_SCREEN_SAVER_PROXY, CsScreenSaverProxyClass))
#define CS_IS_SCREEN_SAVER_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_SCREEN_SAVER_PROXY))
#define CS_IS_SCREEN_SAVER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_SCREEN_SAVER_PROXY))

typedef struct _CsScreenSaverProxy CsScreenSaverProxy;
typedef struct _CsScreenSaverProxyClass CsScreenSaverProxyClass;
typedef struct _CsScreenSaverProxyPrivate CsScreenSaverProxyPrivate;

struct _CsScreenSaverProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  CsScreenSaverProxyPrivate *priv;
};

struct _CsScreenSaverProxyClass
{
  GDBusProxyClass parent_class;
};

GType cs_screen_saver_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsScreenSaverProxy, g_object_unref)
#endif

void cs_screen_saver_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsScreenSaver *cs_screen_saver_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
CsScreenSaver *cs_screen_saver_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void cs_screen_saver_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsScreenSaver *cs_screen_saver_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
CsScreenSaver *cs_screen_saver_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define CS_TYPE_SCREEN_SAVER_SKELETON (cs_screen_saver_skeleton_get_type ())
#define CS_SCREEN_SAVER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_SCREEN_SAVER_SKELETON, CsScreenSaverSkeleton))
#define CS_SCREEN_SAVER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_SCREEN_SAVER_SKELETON, CsScreenSaverSkeletonClass))
#define CS_SCREEN_SAVER_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_SCREEN_SAVER_SKELETON, CsScreenSaverSkeletonClass))
#define CS_IS_SCREEN_SAVER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_SCREEN_SAVER_SKELETON))
#define CS_IS_SCREEN_SAVER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_SCREEN_SAVER_SKELETON))

typedef struct _CsScreenSaverSkeleton CsScreenSaverSkeleton;
typedef struct _CsScreenSaverSkeletonClass CsScreenSaverSkeletonClass;
typedef struct _CsScreenSaverSkeletonPrivate CsScreenSaverSkeletonPrivate;

struct _CsScreenSaverSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  CsScreenSaverSkeletonPrivate *priv;
};

struct _CsScreenSaverSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType cs_screen_saver_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsScreenSaverSkeleton, g_object_unref)
#endif

CsScreenSaver *cs_screen_saver_skeleton_new (void);


G_END_DECLS

#endif /* __CS_SCREENSAVER_PROXY_H__ */
