/*
 * This file is generated by gdbus-codegen, do not modify it.
 *
 * The license of this code is the same as for the D-Bus interface description
 * it was derived from. Note that it links to GLib, so must comply with the
 * LGPL linking clauses.
 */

#ifndef __CS_MEDIA_PLAYER_PROXY_H__
#define __CS_MEDIA_PLAYER_PROXY_H__

#include <gio/gio.h>

G_BEGIN_DECLS


/* ------------------------------------------------------------------------ */
/* Declarations for org.mpris.MediaPlayer2.Player */

#define CS_TYPE_MEDIA_PLAYER (cs_media_player_get_type ())
#define CS_MEDIA_PLAYER(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_MEDIA_PLAYER, CsMediaPlayer))
#define CS_IS_MEDIA_PLAYER(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_MEDIA_PLAYER))
#define CS_MEDIA_PLAYER_GET_IFACE(o) (G_TYPE_INSTANCE_GET_INTERFACE ((o), CS_TYPE_MEDIA_PLAYER, CsMediaPlayerIface))

struct _CsMediaPlayer;
typedef struct _CsMediaPlayer CsMediaPlayer;
typedef struct _CsMediaPlayerIface CsMediaPlayerIface;

struct _CsMediaPlayerIface
{
  GTypeInterface parent_iface;



  gboolean (*handle_next) (
    CsMediaPlayer *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_open_uri) (
    CsMediaPlayer *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_Uri);

  gboolean (*handle_pause) (
    CsMediaPlayer *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_play) (
    CsMediaPlayer *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_play_pause) (
    CsMediaPlayer *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_previous) (
    CsMediaPlayer *object,
    GDBusMethodInvocation *invocation);

  gboolean (*handle_seek) (
    CsMediaPlayer *object,
    GDBusMethodInvocation *invocation,
    gint64 arg_Offset);

  gboolean (*handle_set_position) (
    CsMediaPlayer *object,
    GDBusMethodInvocation *invocation,
    const gchar *arg_TrackId,
    gint64 arg_Position);

  gboolean (*handle_stop) (
    CsMediaPlayer *object,
    GDBusMethodInvocation *invocation);

  gboolean  (*get_can_control) (CsMediaPlayer *object);

  gboolean  (*get_can_go_next) (CsMediaPlayer *object);

  gboolean  (*get_can_go_previous) (CsMediaPlayer *object);

  gboolean  (*get_can_pause) (CsMediaPlayer *object);

  gboolean  (*get_can_play) (CsMediaPlayer *object);

  gboolean  (*get_can_seek) (CsMediaPlayer *object);

  const gchar * (*get_loop_status) (CsMediaPlayer *object);

  gdouble  (*get_maximum_rate) (CsMediaPlayer *object);

  GVariant * (*get_metadata) (CsMediaPlayer *object);

  gdouble  (*get_minimum_rate) (CsMediaPlayer *object);

  const gchar * (*get_playback_status) (CsMediaPlayer *object);

  gint64  (*get_position) (CsMediaPlayer *object);

  gdouble  (*get_rate) (CsMediaPlayer *object);

  gboolean  (*get_shuffle) (CsMediaPlayer *object);

  gdouble  (*get_volume) (CsMediaPlayer *object);

  void (*seeked) (
    CsMediaPlayer *object,
    gint64 arg_Position);

};

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsMediaPlayer, g_object_unref)
#endif

GType cs_media_player_get_type (void) G_GNUC_CONST;

GDBusInterfaceInfo *cs_media_player_interface_info (void);
guint cs_media_player_override_properties (GObjectClass *klass, guint property_id_begin);


/* D-Bus method call completion functions: */
void cs_media_player_complete_next (
    CsMediaPlayer *object,
    GDBusMethodInvocation *invocation);

void cs_media_player_complete_previous (
    CsMediaPlayer *object,
    GDBusMethodInvocation *invocation);

void cs_media_player_complete_pause (
    CsMediaPlayer *object,
    GDBusMethodInvocation *invocation);

void cs_media_player_complete_play_pause (
    CsMediaPlayer *object,
    GDBusMethodInvocation *invocation);

void cs_media_player_complete_stop (
    CsMediaPlayer *object,
    GDBusMethodInvocation *invocation);

void cs_media_player_complete_play (
    CsMediaPlayer *object,
    GDBusMethodInvocation *invocation);

void cs_media_player_complete_seek (
    CsMediaPlayer *object,
    GDBusMethodInvocation *invocation);

void cs_media_player_complete_set_position (
    CsMediaPlayer *object,
    GDBusMethodInvocation *invocation);

void cs_media_player_complete_open_uri (
    CsMediaPlayer *object,
    GDBusMethodInvocation *invocation);



/* D-Bus signal emissions functions: */
void cs_media_player_emit_seeked (
    CsMediaPlayer *object,
    gint64 arg_Position);



/* D-Bus method calls: */
void cs_media_player_call_next (
    CsMediaPlayer *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cs_media_player_call_next_finish (
    CsMediaPlayer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean cs_media_player_call_next_sync (
    CsMediaPlayer *proxy,
    GCancellable *cancellable,
    GError **error);

void cs_media_player_call_previous (
    CsMediaPlayer *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cs_media_player_call_previous_finish (
    CsMediaPlayer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean cs_media_player_call_previous_sync (
    CsMediaPlayer *proxy,
    GCancellable *cancellable,
    GError **error);

void cs_media_player_call_pause (
    CsMediaPlayer *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cs_media_player_call_pause_finish (
    CsMediaPlayer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean cs_media_player_call_pause_sync (
    CsMediaPlayer *proxy,
    GCancellable *cancellable,
    GError **error);

void cs_media_player_call_play_pause (
    CsMediaPlayer *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cs_media_player_call_play_pause_finish (
    CsMediaPlayer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean cs_media_player_call_play_pause_sync (
    CsMediaPlayer *proxy,
    GCancellable *cancellable,
    GError **error);

void cs_media_player_call_stop (
    CsMediaPlayer *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cs_media_player_call_stop_finish (
    CsMediaPlayer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean cs_media_player_call_stop_sync (
    CsMediaPlayer *proxy,
    GCancellable *cancellable,
    GError **error);

void cs_media_player_call_play (
    CsMediaPlayer *proxy,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cs_media_player_call_play_finish (
    CsMediaPlayer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean cs_media_player_call_play_sync (
    CsMediaPlayer *proxy,
    GCancellable *cancellable,
    GError **error);

void cs_media_player_call_seek (
    CsMediaPlayer *proxy,
    gint64 arg_Offset,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cs_media_player_call_seek_finish (
    CsMediaPlayer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean cs_media_player_call_seek_sync (
    CsMediaPlayer *proxy,
    gint64 arg_Offset,
    GCancellable *cancellable,
    GError **error);

void cs_media_player_call_set_position (
    CsMediaPlayer *proxy,
    const gchar *arg_TrackId,
    gint64 arg_Position,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cs_media_player_call_set_position_finish (
    CsMediaPlayer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean cs_media_player_call_set_position_sync (
    CsMediaPlayer *proxy,
    const gchar *arg_TrackId,
    gint64 arg_Position,
    GCancellable *cancellable,
    GError **error);

void cs_media_player_call_open_uri (
    CsMediaPlayer *proxy,
    const gchar *arg_Uri,
    GCancellable *cancellable,
    GAsyncReadyCallback callback,
    gpointer user_data);

gboolean cs_media_player_call_open_uri_finish (
    CsMediaPlayer *proxy,
    GAsyncResult *res,
    GError **error);

gboolean cs_media_player_call_open_uri_sync (
    CsMediaPlayer *proxy,
    const gchar *arg_Uri,
    GCancellable *cancellable,
    GError **error);



/* D-Bus property accessors: */
const gchar *cs_media_player_get_playback_status (CsMediaPlayer *object);
gchar *cs_media_player_dup_playback_status (CsMediaPlayer *object);
void cs_media_player_set_playback_status (CsMediaPlayer *object, const gchar *value);

const gchar *cs_media_player_get_loop_status (CsMediaPlayer *object);
gchar *cs_media_player_dup_loop_status (CsMediaPlayer *object);
void cs_media_player_set_loop_status (CsMediaPlayer *object, const gchar *value);

gdouble cs_media_player_get_rate (CsMediaPlayer *object);
void cs_media_player_set_rate (CsMediaPlayer *object, gdouble value);

gboolean cs_media_player_get_shuffle (CsMediaPlayer *object);
void cs_media_player_set_shuffle (CsMediaPlayer *object, gboolean value);

GVariant *cs_media_player_get_metadata (CsMediaPlayer *object);
GVariant *cs_media_player_dup_metadata (CsMediaPlayer *object);
void cs_media_player_set_metadata (CsMediaPlayer *object, GVariant *value);

gdouble cs_media_player_get_volume (CsMediaPlayer *object);
void cs_media_player_set_volume (CsMediaPlayer *object, gdouble value);

gint64 cs_media_player_get_position (CsMediaPlayer *object);
void cs_media_player_set_position (CsMediaPlayer *object, gint64 value);

gdouble cs_media_player_get_minimum_rate (CsMediaPlayer *object);
void cs_media_player_set_minimum_rate (CsMediaPlayer *object, gdouble value);

gdouble cs_media_player_get_maximum_rate (CsMediaPlayer *object);
void cs_media_player_set_maximum_rate (CsMediaPlayer *object, gdouble value);

gboolean cs_media_player_get_can_go_next (CsMediaPlayer *object);
void cs_media_player_set_can_go_next (CsMediaPlayer *object, gboolean value);

gboolean cs_media_player_get_can_go_previous (CsMediaPlayer *object);
void cs_media_player_set_can_go_previous (CsMediaPlayer *object, gboolean value);

gboolean cs_media_player_get_can_play (CsMediaPlayer *object);
void cs_media_player_set_can_play (CsMediaPlayer *object, gboolean value);

gboolean cs_media_player_get_can_pause (CsMediaPlayer *object);
void cs_media_player_set_can_pause (CsMediaPlayer *object, gboolean value);

gboolean cs_media_player_get_can_seek (CsMediaPlayer *object);
void cs_media_player_set_can_seek (CsMediaPlayer *object, gboolean value);

gboolean cs_media_player_get_can_control (CsMediaPlayer *object);
void cs_media_player_set_can_control (CsMediaPlayer *object, gboolean value);


/* ---- */

#define CS_TYPE_MEDIA_PLAYER_PROXY (cs_media_player_proxy_get_type ())
#define CS_MEDIA_PLAYER_PROXY(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_MEDIA_PLAYER_PROXY, CsMediaPlayerProxy))
#define CS_MEDIA_PLAYER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_MEDIA_PLAYER_PROXY, CsMediaPlayerProxyClass))
#define CS_MEDIA_PLAYER_PROXY_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_MEDIA_PLAYER_PROXY, CsMediaPlayerProxyClass))
#define CS_IS_MEDIA_PLAYER_PROXY(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_MEDIA_PLAYER_PROXY))
#define CS_IS_MEDIA_PLAYER_PROXY_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_MEDIA_PLAYER_PROXY))

typedef struct _CsMediaPlayerProxy CsMediaPlayerProxy;
typedef struct _CsMediaPlayerProxyClass CsMediaPlayerProxyClass;
typedef struct _CsMediaPlayerProxyPrivate CsMediaPlayerProxyPrivate;

struct _CsMediaPlayerProxy
{
  /*< private >*/
  GDBusProxy parent_instance;
  CsMediaPlayerProxyPrivate *priv;
};

struct _CsMediaPlayerProxyClass
{
  GDBusProxyClass parent_class;
};

GType cs_media_player_proxy_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsMediaPlayerProxy, g_object_unref)
#endif

void cs_media_player_proxy_new (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsMediaPlayer *cs_media_player_proxy_new_finish (
    GAsyncResult        *res,
    GError             **error);
CsMediaPlayer *cs_media_player_proxy_new_sync (
    GDBusConnection     *connection,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);

void cs_media_player_proxy_new_for_bus (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GAsyncReadyCallback  callback,
    gpointer             user_data);
CsMediaPlayer *cs_media_player_proxy_new_for_bus_finish (
    GAsyncResult        *res,
    GError             **error);
CsMediaPlayer *cs_media_player_proxy_new_for_bus_sync (
    GBusType             bus_type,
    GDBusProxyFlags      flags,
    const gchar         *name,
    const gchar         *object_path,
    GCancellable        *cancellable,
    GError             **error);


/* ---- */

#define CS_TYPE_MEDIA_PLAYER_SKELETON (cs_media_player_skeleton_get_type ())
#define CS_MEDIA_PLAYER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_CAST ((o), CS_TYPE_MEDIA_PLAYER_SKELETON, CsMediaPlayerSkeleton))
#define CS_MEDIA_PLAYER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_CAST ((k), CS_TYPE_MEDIA_PLAYER_SKELETON, CsMediaPlayerSkeletonClass))
#define CS_MEDIA_PLAYER_SKELETON_GET_CLASS(o) (G_TYPE_INSTANCE_GET_CLASS ((o), CS_TYPE_MEDIA_PLAYER_SKELETON, CsMediaPlayerSkeletonClass))
#define CS_IS_MEDIA_PLAYER_SKELETON(o) (G_TYPE_CHECK_INSTANCE_TYPE ((o), CS_TYPE_MEDIA_PLAYER_SKELETON))
#define CS_IS_MEDIA_PLAYER_SKELETON_CLASS(k) (G_TYPE_CHECK_CLASS_TYPE ((k), CS_TYPE_MEDIA_PLAYER_SKELETON))

typedef struct _CsMediaPlayerSkeleton CsMediaPlayerSkeleton;
typedef struct _CsMediaPlayerSkeletonClass CsMediaPlayerSkeletonClass;
typedef struct _CsMediaPlayerSkeletonPrivate CsMediaPlayerSkeletonPrivate;

struct _CsMediaPlayerSkeleton
{
  /*< private >*/
  GDBusInterfaceSkeleton parent_instance;
  CsMediaPlayerSkeletonPrivate *priv;
};

struct _CsMediaPlayerSkeletonClass
{
  GDBusInterfaceSkeletonClass parent_class;
};

GType cs_media_player_skeleton_get_type (void) G_GNUC_CONST;

#if GLIB_CHECK_VERSION(2, 44, 0)
G_DEFINE_AUTOPTR_CLEANUP_FUNC (CsMediaPlayerSkeleton, g_object_unref)
#endif

CsMediaPlayer *cs_media_player_skeleton_new (void);


G_END_DECLS

#endif /* __CS_MEDIA_PLAYER_PROXY_H__ */
